===============================
PyIslands
===============================

.. image:: https://badge.fury.io/py/pyislands.png
    :target: http://badge.fury.io/py/pyislands

.. image:: https://travis-ci.org/sglumac/pyislands.png?branch=master
        :target: https://travis-ci.org/sglumac/pyislands

.. image:: https://pypip.in/d/pyislands/badge.png
        :target: https://pypi.python.org/pypi/pyislands


PyIslands contains an implementation of islands genetic algorithms.

* Free software: MIT license
* Documentation: https://pyislands.readthedocs.org.

Features
--------

* TODO
